//
//  BigLetterView.m
//  TypingTutor
//
//  Created by Robert on 8/5/18.
//  Copyright © 2018 isovega. All rights reserved.
//

#import "BigLetterView.h"

@implementation BigLetterView

- (void)drawRect:(NSRect)dirtyRect {
    [self prepareAttributes];
    [super drawRect:dirtyRect];
    NSRect bounds = [self bounds];
    [bgColor set];
    [NSBezierPath fillRect:bounds];
    
    [self drawStringCenteredIn:bounds];
    
    if ([[self window] firstResponder] == self) {
        
    }
    // Drawing code here.
}

- (id)initWithFrame:(NSRect)frame {
    self = [super initWithFrame:frame];
    
    if (self) {
        NSLog(@"initializing view with frame");
        [self prepareAttributes];
        bgColor = [NSColor grayColor];
        string = @" ";
    }
    
    textSize = 50;
    bold = italic = NO;
    
    return self;
}

- (BOOL)isOpaque {
    return YES;
}

- (BOOL)acceptsFirstResponder
{
    NSLog(@"Accepting");
    return YES;
}

- (void)drawFocusRingMask
{
    NSRectFill([self bounds]);
}

- (NSRect)focusRingMaskBounds
{
    return [self bounds];
}
   
- (BOOL)resignFirstResponder
{
    NSLog(@"Resigning");
    [self setNeedsDisplay:YES];
    return YES;
}

- (BOOL)becomeFirstResponder
{
    NSLog(@"Becoming");
    [self setNeedsDisplay:YES];
    return YES;
}

- (void)keyDown:(NSEvent *)event
{
    [self interpretKeyEvents:[NSArray arrayWithObject:event]];
}

- (void)insertText:(NSString *)input
{
    [self setString:input];
    [self setNeedsDisplay:YES];
}

- (void)insertTab:(id)sender
{
    [[self window] selectKeyViewFollowingView:self];
}

- (void)insertBacktab:(id)sender
{
    [[self window] selectKeyViewPrecedingView:self];
}

- (void)deleteBackward:(id)sender
{
    [self setString:@" "];
}

- (void)prepareAttributes
{
    NSFont *f;
    NSFontManager *fontManager;
    
    f = [NSFont userFontOfSize:textSize];
    fontManager = [NSFontManager sharedFontManager];

    if (bold) {
        f = [fontManager convertFont:f toHaveTrait:NSBoldFontMask];
    }
    
    if (italic) {
        f = [fontManager convertFont:f toHaveTrait:NSItalicFontMask];
    }

    attributes = [NSMutableDictionary dictionary];
    [attributes setObject:f
                   forKey:NSFontAttributeName];
    [attributes setObject:[NSColor blackColor]
                   forKey:NSForegroundColorAttributeName];
}

- (void)drawStringCenteredIn:(NSRect)r
{
    NSSize strSize = [string sizeWithAttributes:attributes];
    NSPoint strOrigin;
    strOrigin.x = r.origin.x + (r.size.width - strSize.width) / 2;
    strOrigin.y = r.origin.y + (r.size.height - strSize.height) / 2;
    [string drawAtPoint:strOrigin withAttributes:attributes];
}

#pragma mark Accessors

- (void)setBGColor:(NSColor *)c {
    bgColor = c;
    [self setNeedsDisplay:YES];
}

- (NSColor *)bgColor {
    return bgColor;
}

- (void)setString:(NSString *)c {
    string = c;
    NSLog(@"The string is now %@", string);
}

- (NSString *)string {
    return string;
}

- (IBAction)boldIt:(id)sender {
    bold = [sender state];
    NSLog(@"boldIt: sender state = %d", [sender state]);
}

- (IBAction)italicizeIt:(id)sender {
    italic = [sender state];
}

- (IBAction)sizeSlider:(id)sender {
    textSize = [sender intValue];
    [self setNeedsDisplay:YES];
}

@end
